@@ -32,8 +32,6 @@ describe 'keystone' do
 
       it 'should set the default values' do
         is_expected.to contain_resources('keystone_config').with({ :purge => false })
-        is_expected.to contain_keystone_config('DEFAULT/member_role_id').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('DEFAULT/member_role_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('token/expiration').with_value(3600)
         is_expected.to contain_keystone_config('identity/password_hash_algorithm').with_value('<SERVICE DEFAULT>')
@@ -41,6 +39,11 @@ describe 'keystone' do
         is_expected.to contain_keystone_config('revoke/driver').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('policy/driver').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('ssl/enable').with_value(false)
+        is_expected.to contain_keystone_config('ssl/certfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/keyfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/ca_certs').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/ca_key').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/cert_subject').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('token/revoke_by_id').with_value(true)
 
         is_expected.to contain_oslo__middleware('keystone_config').with(
@@ -96,14 +99,27 @@ describe 'keystone' do
       it { is_expected.to contain_exec('keystone-manage db_sync') }
 
       it { is_expected.to_not contain_file('/etc/keystone/domains') }
+
+      it { is_expected.to contain_file('/etc/keystone/credential-keys').with(
+        :ensure => 'directory',
+        :owner  => 'keystone',
+        :group  => 'keystone',
+        'mode'  => '0600',
+      ) }
+
+      it { is_expected.to contain_exec('keystone-manage credential_setup').with(
+        :command => 'keystone-manage credential_setup --keystone-user keystone --keystone-group keystone',
+        :user    => 'keystone',
+        :creates => '/etc/keystone/credential-keys/0',
+        :require => 'File[/etc/keystone/credential-keys]',
+      ) }
+      it { is_expected.to contain_keystone_config('credential/key_repository').with_value('/etc/keystone/credential-keys')}
     end
 
     context 'with overridden parameters' do
       let :params do
         {
           :purge_config                 => true,
-          :member_role_id               => 'someid',
-          :member_role_name             => 'member',
           :public_endpoint              => 'http://127.0.0.1:5000',
           :token_expiration             => 7200,
           :password_hash_algorithm      => 'bcrypt',
@@ -113,7 +129,7 @@ describe 'keystone' do
           :revoke_by_id                 => true,
           :enable_proxy_headers_parsing => true,
           :max_request_body_size        => 114688,
-          :catalog_type                 => 'template',
+          :catalog_driver               => 'templated',
           :catalog_template_file        => '/some/template_file',
           :token_provider               => 'uuid',
           :max_token_size               => 255,
@@ -123,8 +139,6 @@ describe 'keystone' do
 
       it 'should set the overridden values' do
         is_expected.to contain_resources('keystone_config').with({ :purge => true })
-        is_expected.to contain_keystone_config('DEFAULT/member_role_id').with_value('someid')
-        is_expected.to contain_keystone_config('DEFAULT/member_role_name').with_value('member')
         is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('http://127.0.0.1:5000')
         is_expected.to contain_keystone_config('token/expiration').with_value(7200)
         is_expected.to contain_keystone_config('identity/password_hash_algorithm').with_value('bcrypt')
@@ -132,6 +146,11 @@ describe 'keystone' do
         is_expected.to contain_keystone_config('revoke/driver').with_value('sql')
         is_expected.to contain_keystone_config('policy/driver').with_value('sql')
         is_expected.to contain_keystone_config('ssl/enable').with_value(false)
+        is_expected.to contain_keystone_config('ssl/certfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/keyfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/ca_certs').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/ca_key').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/cert_subject').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('token/revoke_by_id').with_value(true)
 
         is_expected.to contain_oslo__middleware('keystone_config').with(
@@ -164,7 +183,7 @@ describe 'keystone' do
       end
 
       it { is_expected.to contain_exec('restart_keystone').with(
-        'command' => "service #{platform_params[:httpd_service_name]} restart",
+        'command' => "systemctl restart #{platform_params[:httpd_service_name]}",
       ) }
     end
 
@@ -178,17 +197,10 @@ describe 'keystone' do
 
     context 'with disabled service managing' do
       let :params do
-        { :manage_service => false,
-          :enabled        => false }
+        { :manage_service => false }
       end
 
-      it { is_expected.to contain_service('keystone').with(
-        'ensure'     => nil,
-        'enable'     => false,
-        'hasstatus'  => true,
-        'hasrestart' => true
-      ) }
-      it { is_expected.to contain_anchor('keystone::service::end') }
+      it { is_expected.to_not contain_service('keystone') }
     end
 
     context 'with invalid catalog_type' do
@@ -299,28 +311,16 @@ describe 'keystone' do
       ) }
     end
 
-    context 'when enabling credential_setup' do
+    context 'when disabling credential_setup' do
       let :params do
         {
-          'enable_credential_setup'   => true,
-          'credential_key_repository' => '/etc/keystone/credential-keys',
+          'enable_credential_setup' => false,
         }
       end
 
-      it { is_expected.to contain_file(params['credential_key_repository']).with(
-        :ensure => 'directory',
-        :owner  => 'keystone',
-        :group  => 'keystone',
-        'mode'  => '0600',
-      ) }
-
-      it { is_expected.to contain_exec('keystone-manage credential_setup').with(
-        :command => 'keystone-manage credential_setup --keystone-user keystone --keystone-group keystone',
-        :user    => 'keystone',
-        :creates => '/etc/keystone/credential-keys/0',
-        :require => 'File[/etc/keystone/credential-keys]',
-      ) }
-      it { is_expected.to contain_keystone_config('credential/key_repository').with_value('/etc/keystone/credential-keys')}
+      it { is_expected.to_not contain_file('/etc/keystone/credential-keys') }
+      it { is_expected.to_not contain_exec('keystone-manage credential_setup') }
+      it { is_expected.to contain_keystone_config('credential/key_repository').with_value('/etc/keystone/credential-keys') }
     end
 
     context 'when overriding the credential key directory' do
@@ -331,9 +331,16 @@ describe 'keystone' do
         }
       end
 
+      it { is_expected.to contain_file('/var/lib/credential-keys').with(
+        :ensure => 'directory',
+        :owner  => 'keystone',
+        :group  => 'keystone',
+        'mode'  => '0600',
+      ) }
       it { is_expected.to contain_exec('keystone-manage credential_setup').with(
         :creates => '/var/lib/credential-keys/0'
       ) }
+      it { is_expected.to contain_keystone_config('credential/key_repository').with_value('/var/lib/credential-keys') }
     end
 
     context 'when overriding the keystone group and user' do
@@ -524,7 +531,7 @@ describe 'keystone' do
       end
 
       it { is_expected.to contain_exec('restart_keystone').with(
-        'command' => "service #{platform_params[:service_name]} restart",
+        'command' => "systemctl restart #{platform_params[:service_name]}",
       ) }
       it { is_expected.to contain_anchor('default_domain_created') }
     end
@@ -620,7 +627,7 @@ describe 'keystone' do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts({
           :concat_basedir => '/var/lib/puppet/concat',
-          :fqdn           => 'some.host.tld'
+          :fqdn           => 'some.host.tld',
         }))
       end
 
