@@ -10,7 +10,7 @@ describe Puppet::Type.type(:keystone_user).provider(:openstack) do
   let(:set_env) do
     ENV['OS_USERNAME']     = 'test'
     ENV['OS_PASSWORD']     = 'abc123'
-    ENV['OS_PROJECT_NAME'] = 'test'
+    ENV['OS_SYSTEM_SCOPE'] = 'all'
     ENV['OS_AUTH_URL']     = 'http://127.0.0.1:5000'
   end
 
